/*
 * win_res.h - constants shared between win_res.rc2 and the C code.
 */

#ifndef PUTTY_WIN_RES_H
#define PUTTY_WIN_RES_H

#define IDI_MAINICON     200
#define IDI_CFGICON      201

#define IDD_MAINBOX      102
#define IDD_LOGBOX       110
#define IDD_ABOUTBOX     111
#define IDD_RECONF       112
#define IDD_LICENCEBOX   113
#define IDD_HK_ABSENT    114
#define IDD_HK_WRONG     115
#define IDD_HK_MOREINFO  116

#define IDN_LIST        1001
#define IDN_COPY        1002

#define IDA_ICON        1001
#define IDA_TEXT        1002
#define IDA_LICENCE     1003
#define IDA_WEB         1004

#define IDC_TAB         1001
#define IDC_TABSTATIC1  1002
#define IDC_TABSTATIC2  1003
#define IDC_TABLIST     1004
#define IDC_HELPBTN     1005
#define IDC_ABOUT       1006

#define IDC_HK_ICON       98
#define IDC_HK_TITLE      99
#define IDC_HK_ACCEPT   1001
#define IDC_HK_ONCE     1000
#define IDC_HK_FINGERPRINT 1002
#define IDC_HK_MOREINFO 1003

#define IDC_HKI_SHA256  1000
#define IDC_HKI_MD5     1001
#define IDC_HKI_PUBKEY  1002

#define ID_CUSTOM_CHMFILE 2000
#define TYPE_CUSTOM_CHMFILE 2000

#endif
